@@ -4,7 +4,7 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 )
 
 // UpdateConditionCheck tests whether a condition should be updated from the
@@ -41,6 +41,26 @@ func shouldUpdateCondition(
 	return updateConditionCheck(oldReason, oldMessage, newReason, newMessage)
 }
 
+// InitializeClusterDeploymentConditions initializes the given set of conditions for the first time, set with Status Unknown
+func InitializeClusterDeploymentConditions(existingConditions []hivev1.ClusterDeploymentCondition, conditionsToBeAdded []hivev1.ClusterDeploymentConditionType) []hivev1.ClusterDeploymentCondition {
+	now := metav1.Now()
+	for _, conditionType := range conditionsToBeAdded {
+		if FindClusterDeploymentCondition(existingConditions, conditionType) == nil {
+			existingConditions = append(
+				existingConditions,
+				hivev1.ClusterDeploymentCondition{
+					Type:               conditionType,
+					Status:             corev1.ConditionUnknown,
+					Reason:             hivev1.InitializedConditionReason,
+					Message:            "Condition Initialized",
+					LastTransitionTime: now,
+					LastProbeTime:      now,
+				})
+		}
+	}
+	return existingConditions
+}
+
 // SetClusterDeploymentCondition sets a condition on a ClusterDeployment resource's status
 func SetClusterDeploymentCondition(
 	conditions []hivev1.ClusterDeploymentCondition,
@@ -144,20 +164,22 @@ func SetClusterClaimConditionWithChangeCheck(
 	now := metav1.Now()
 	existingCondition := FindClusterClaimCondition(conditions, conditionType)
 	if existingCondition == nil {
-		if status == corev1.ConditionTrue {
-			conditions = append(
-				conditions,
-				hivev1.ClusterClaimCondition{
-					Type:               conditionType,
-					Status:             status,
-					Reason:             reason,
-					Message:            message,
-					LastTransitionTime: now,
-					LastProbeTime:      now,
-				},
-			)
-			changed = true
-		}
+		// Deviating from other setter methods we use due to latest API conventions in Kube. They clarify that a
+		// True condition is not necessarily an abnormal state, and that conditions should be set asap even if Unknown.
+		// Previously we would not bother setting the condition if the status was false. With ClusterClaim we are
+		// beginning to adhere to these guidelines.
+		conditions = append(
+			conditions,
+			hivev1.ClusterClaimCondition{
+				Type:               conditionType,
+				Status:             status,
+				Reason:             reason,
+				Message:            message,
+				LastTransitionTime: now,
+				LastProbeTime:      now,
+			},
+		)
+		changed = true
 	} else {
 		if shouldUpdateCondition(
 			existingCondition.Status, existingCondition.Reason, existingCondition.Message,
@@ -212,20 +234,22 @@ func SetClusterPoolConditionWithChangeCheck(
 	now := metav1.Now()
 	existingCondition := FindClusterPoolCondition(conditions, conditionType)
 	if existingCondition == nil {
-		if status == corev1.ConditionTrue {
-			conditions = append(
-				conditions,
-				hivev1.ClusterPoolCondition{
-					Type:               conditionType,
-					Status:             status,
-					Reason:             reason,
-					Message:            message,
-					LastTransitionTime: now,
-					LastProbeTime:      now,
-				},
-			)
-			changed = true
-		}
+		// Deviating from other setter methods we use due to latest API conventions in Kube. They clarify that a
+		// True condition is not necessarily an abnormal state, and that conditions should be set asap even if Unknown.
+		// Previously we would not bother setting the condition if the status was false. With ClusterClaim we are
+		// beginning to adhere to these guidelines.
+		conditions = append(
+			conditions,
+			hivev1.ClusterPoolCondition{
+				Type:               conditionType,
+				Status:             status,
+				Reason:             reason,
+				Message:            message,
+				LastTransitionTime: now,
+				LastProbeTime:      now,
+			},
+		)
+		changed = true
 	} else {
 		if shouldUpdateCondition(
 			existingCondition.Status, existingCondition.Reason, existingCondition.Message,
@@ -467,6 +491,122 @@ func SetMachinePoolConditionWithChangeCheck(
 	return conditions, changed
 }
 
+// SetClusterDeprovisionCondition sets a condition on a ClusterDeprovision resource's status
+func SetClusterDeprovisionCondition(
+	conditions []hivev1.ClusterDeprovisionCondition,
+	conditionType hivev1.ClusterDeprovisionConditionType,
+	status corev1.ConditionStatus,
+	reason string,
+	message string,
+	updateConditionCheck UpdateConditionCheck,
+) []hivev1.ClusterDeprovisionCondition {
+	newConditions, _ := SetClusterDeprovisionConditionWithChangeCheck(
+		conditions,
+		conditionType,
+		status,
+		reason,
+		message,
+		updateConditionCheck,
+	)
+	return newConditions
+}
+
+// SetClusterDeprovisionConditionWithChangeCheck sets a condition on a ClusterDeprovision resource's status
+// It returns the conditions as well a boolean indicating whether there was a change made
+// to the conditions.
+func SetClusterDeprovisionConditionWithChangeCheck(
+	conditions []hivev1.ClusterDeprovisionCondition,
+	conditionType hivev1.ClusterDeprovisionConditionType,
+	status corev1.ConditionStatus,
+	reason string,
+	message string,
+	updateConditionCheck UpdateConditionCheck,
+) ([]hivev1.ClusterDeprovisionCondition, bool) {
+	changed := false
+	now := metav1.Now()
+	existingCondition := FindClusterDeprovisionCondition(conditions, conditionType)
+	if existingCondition == nil {
+		if status == corev1.ConditionTrue {
+			conditions = append(
+				conditions,
+				hivev1.ClusterDeprovisionCondition{
+					Type:               conditionType,
+					Status:             status,
+					Reason:             reason,
+					Message:            message,
+					LastTransitionTime: now,
+					LastProbeTime:      now,
+				},
+			)
+			changed = true
+		}
+	} else {
+		if shouldUpdateCondition(
+			existingCondition.Status, existingCondition.Reason, existingCondition.Message,
+			status, reason, message,
+			updateConditionCheck,
+		) {
+			if existingCondition.Status != status {
+				existingCondition.LastTransitionTime = now
+			}
+			existingCondition.Status = status
+			existingCondition.Reason = reason
+			existingCondition.Message = message
+			existingCondition.LastProbeTime = now
+			changed = true
+		}
+	}
+	return conditions, changed
+}
+
+// SetClusterInstallConditionWithChangeCheck sets a condition in the list of status conditions
+// for a ClusterInstall implementation.
+// It returns the resulting conditions as well a boolean indicating whether there was a change made
+// to the conditions.
+func SetClusterInstallConditionWithChangeCheck(
+	conditions []hivev1.ClusterInstallCondition,
+	conditionType string,
+	status corev1.ConditionStatus,
+	reason string,
+	message string,
+	updateConditionCheck UpdateConditionCheck,
+) ([]hivev1.ClusterInstallCondition, bool) {
+
+	changed := false
+	now := metav1.Now()
+	existingCondition := FindClusterInstallCondition(conditions, conditionType)
+	if existingCondition == nil {
+		conditions = append(
+			conditions,
+			hivev1.ClusterInstallCondition{
+				Type:               conditionType,
+				Status:             status,
+				Reason:             reason,
+				Message:            message,
+				LastTransitionTime: now,
+				LastProbeTime:      now,
+			},
+		)
+		changed = true
+	} else {
+		if shouldUpdateCondition(
+			existingCondition.Status, existingCondition.Reason, existingCondition.Message,
+			status, reason, message,
+			updateConditionCheck,
+		) {
+			if existingCondition.Status != status {
+				existingCondition.LastTransitionTime = now
+			}
+			existingCondition.Status = status
+			existingCondition.Reason = reason
+			existingCondition.Message = message
+			existingCondition.LastProbeTime = now
+			changed = true
+		}
+	}
+	return conditions, changed
+}
+
 // FindClusterDeploymentCondition finds in the condition that has the
 // specified condition type in the given list. If none exists, then returns nil.
 func FindClusterDeploymentCondition(conditions []hivev1.ClusterDeploymentCondition, conditionType hivev1.ClusterDeploymentConditionType) *hivev1.ClusterDeploymentCondition {
@@ -543,3 +683,25 @@ func FindMachinePoolCondition(conditions []hivev1.MachinePoolCondition, conditio
 	}
 	return nil
 }
+
+// FindClusterDeprovisionCondition finds in the condition that has the
+// specified condition type in the given list. If none exists, then returns nil.
+func FindClusterDeprovisionCondition(conditions []hivev1.ClusterDeprovisionCondition, conditionType hivev1.ClusterDeprovisionConditionType) *hivev1.ClusterDeprovisionCondition {
+	for i, condition := range conditions {
+		if condition.Type == conditionType {
+			return &conditions[i]
+		}
+	}
+	return nil
+}
+
+// FindClusterInstallCondition finds in the condition that has the
+// specified condition type in the given list. If none exists, then returns nil.
+func FindClusterInstallCondition(conditions []hivev1.ClusterInstallCondition, conditionType string) *hivev1.ClusterInstallCondition {
+	for i, condition := range conditions {
+		if condition.Type == conditionType {
+			return &conditions[i]
+		}
+	}
+	return nil
+}
